@@ -18,7 +18,7 @@ BEGIN
     $extra = 1
         if $st ;
 
-    plan(tests => 639 + $extra) ;
+    plan(tests => 670 + $extra) ;
 }
 
 sub myGZreadFile
@@ -47,6 +47,7 @@ sub run
     my $Error           = getErrorRef($CompressClass);
     my $UnError         = getErrorRef($UncompressClass);
 
+    if(1)
     {
 
         title "Testing $CompressClass Errors";
@@ -81,7 +82,7 @@ sub run
         like $@, mkEvalErr("^${CompressClass}::write: offset outside string");
 
         eval ' $gz->syswrite("abc", 1, -4)' ;
-        like $@, mkEvalErr("^${CompressClass}::write: offset outside string");
+        like $@, mkEvalErr("^${CompressClass}::write: offset outside string"), "write outside string";
     }
 
 
@@ -161,7 +162,6 @@ sub run
 
 
             my $lex = new LexFile my $name ;
-            #my $name = "/tmp/try.lzf";
 
             my $hello = <<EOM ;
 hello world
@@ -322,7 +322,6 @@ EOM
 
               ok $x->close, "  close" ;
             }
-            #exit;
 
             is $uncomp, $hello, "  expected output" ;
         }
@@ -419,11 +418,11 @@ EOM
               ok ! defined $x->fileno() ;
               1 while $x->read($uncomp) > 0  ;
 
-              ok $x->close ;
+              ok $x->close, "closed" ;
             }
 
-            is $uncomp, $hello ;
-            ok $buffer eq $keep ;
+            is $uncomp, $hello, "got expected uncompressed data" ;
+            ok $buffer eq $keep, "compressed input not changed" ;
         }
 
         if ($CompressClass ne 'RawDeflate')
@@ -434,8 +433,9 @@ EOM
             my $buffer = '';
             {
               my $x ;
-              ok $x = new $CompressClass(\$buffer) ;
-              ok $x->close ;
+              $x = new $CompressClass(\$buffer);
+              ok $x, "new $CompressClass" ;
+              ok $x->close, "close ok" ;
           
             }
 
@@ -541,7 +541,6 @@ EOM
             read($fh1, $rest, 5000);
             is $x->trailingData() . $rest, $trailer ;
             #print "# [".$x->trailingData() . "][$rest]\n" ;
-            #exit;
 
         }
 
@@ -612,7 +611,7 @@ EOM
             my $foo = "1234567890";
             
             is $io->syswrite($foo, length($foo)), length($foo), "  syswrite ok" ;
-            if ( $[ < 5.6 )
+            if ( $] < 5.6 )
               { is $io->syswrite($foo, length $foo), length $foo, "  syswrite ok" }
             else
               { is $io->syswrite($foo), length $foo, "  syswrite ok" }
@@ -653,7 +652,9 @@ EOT
 
             my %opts = () ;
             my $iow = new $CompressClass $name, %opts;
+            is $iow->input_line_number, undef; 
             $iow->print($str) ;
+            is $iow->input_line_number, undef; 
             $iow->close ;
 
             my @tmp;
@@ -779,7 +780,9 @@ EOT
                 eval { $io->read(1) } ;
                 like $@, mkErr("buffer parameter is read-only");
 
+                $buf = "abcd";
                 is $io->read($buf, 0), 0, "Requested 0 bytes" ;
+                is $buf, "", "Buffer empty";
 
                 is $io->read($buf, 3), 3 ;
                 is $buf, "Thi";
@@ -789,6 +792,30 @@ EOT
                     or print "# [$buf]\n" ;;
                 ok ! $io->eof;
             
+                $buf = "ab" ;
+                is $io->read($buf, 3, 4), 3 ;
+                is $buf, "ab" . "\x00" x 2 . "s a"
+                    or print "# [$buf]\n" ;;
+                ok ! $io->eof;
+            
+                # read the rest of the file
+                $buf = '';
+                my $remain = length($str) - 9;
+                is $io->read($buf, $remain+1), $remain ;
+                is $buf, substr($str, 9);
+                ok $io->eof;
+
+                $buf = "hello";
+                is $io->read($buf, 10), 0 ;
+                is $buf, "", "Buffer empty";
+                ok $io->eof;
+
+                ok $io->close();
+                $buf = "hello";
+                is $io->read($buf, 10), 0 ;
+                is $buf, "hello", "Buffer not empty";
+                ok $io->eof;
+
         #        $io->seek(-4, 2);
         #    
         #        ok ! $io->eof;
@@ -928,11 +955,15 @@ EOT
             }
             
             
-            # Test read
+            # Test Read
             
             {
                 my $io = $UncompressClass->new($name);
             
+                $buf = "abcd";
+                is $io->read($buf, 0), 0, "Requested 0 bytes" ;
+                is $buf, "", "Buffer empty";
+
                 ok $io->read($buf, 3) == 3 ;
                 ok $buf eq "Thi";
             
@@ -940,6 +971,30 @@ EOT
                 ok $buf eq "Ths i";
                 ok ! $io->eof;
             
+                $buf = "ab" ;
+                is $io->read($buf, 3, 4), 3 ;
+                is $buf, "ab" . "\x00" x 2 . "s a"
+                    or print "# [$buf]\n" ;;
+                ok ! $io->eof;
+            
+                # read the rest of the file
+                $buf = '';
+                my $remain = length($str) - 9;
+                is $io->read($buf, $remain), $remain ;
+                is $buf, substr($str, 9);
+                ok $io->eof;
+
+                $buf = "hello";
+                is $io->read($buf, 10), 0 ;
+                is $buf, "", "Buffer empty";
+                ok $io->eof;
+
+                ok $io->close();
+                $buf = "hello";
+                is $io->read($buf, 10), 0 ;
+                is $buf, "hello", "Buffer not empty";
+                ok $io->eof;
+
         #        $io->seek(-4, 2);
         #    
         #        ok ! $io->eof;
@@ -1360,7 +1415,6 @@ EOT
             }
         }
 
-
         {
             title "write tests - invalid data" ;
 
